==> haskell-mono-traversable-1.0.15.3-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mono-traversable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mono-traversable
version:              1.0.15.3
visibility:           public
id:                   mono-traversable-1.0.15.3-LJbpO3Bsb1iFgUSFaWhwjJ
key:                  mono-traversable-1.0.15.3-LJbpO3Bsb1iFgUSFaWhwjJ
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, John Wiegley, Greg Weber
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Type classes for mapping, folding, and traversing monomorphic containers

description:
    Please see the README at <https://www.stackage.org/package/mono-traversable>

category:             Data
abi:                  d3f5d8d8ef2201bfce9a5a749da87ce2
exposed:              True
exposed-modules:
    Data.Containers Data.MonoTraversable
    Data.MonoTraversable.Unprefixed Data.NonNull Data.Sequences

hidden-modules:       Paths_mono_traversable
import-dirs:          /usr/lib/ghc-9.0.1/site-local/mono-traversable-1.0.15.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/mono-traversable-1.0.15.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/mono-traversable-1.0.15.3
hs-libraries:         HSmono-traversable-1.0.15.3-LJbpO3Bsb1iFgUSFaWhwjJ
depends:
    base-4.15.0.0 bytestring-0.10.12.1 containers-0.6.4.1
    hashable-1.3.3.0-3L81lU2ygSqqBRC8gEHN5
    split-0.2.3.4-nugq0vWLHr1Xv58VTP1Gn text-1.2.4.1
    transformers-0.5.6.2
    unordered-containers-0.2.14.0-BWkUXYfn3WoA4YwHbxKABd
    vector-0.12.3.1-4LU8STmHsbh153eRU0hKX2
    vector-algorithms-0.8.0.4-391rs1LJ1JCEltIYr3o0AH

haddock-interfaces:
    /usr/share/doc/haskell-mono-traversable/html/mono-traversable.haddock

haddock-html:         /usr/share/doc/haskell-mono-traversable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mono-traversable-1.0.15.3-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mono-traversable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mono-traversable
version:              1.0.15.3
visibility:           public
id:                   mono-traversable-1.0.15.3-FGt6kRgoLlv2QwJjnNTKWl
key:                  mono-traversable-1.0.15.3-FGt6kRgoLlv2QwJjnNTKWl
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, John Wiegley, Greg Weber
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:
    Type classes for mapping, folding, and traversing monomorphic containers

description:
    Please see the README at <https://www.stackage.org/package/mono-traversable>

category:             Data
abi:                  de3d7fa1dd97c5011d68328149845d2b
exposed:              True
exposed-modules:
    Data.Containers Data.MonoTraversable
    Data.MonoTraversable.Unprefixed Data.NonNull Data.Sequences

hidden-modules:       Paths_mono_traversable
import-dirs:          /usr/lib/ghc-9.0.1/site-local/mono-traversable-1.0.15.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/mono-traversable-1.0.15.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/mono-traversable-1.0.15.3
hs-libraries:         HSmono-traversable-1.0.15.3-FGt6kRgoLlv2QwJjnNTKWl
depends:
    base-4.15.0.0 bytestring-0.10.12.1 containers-0.6.4.1
    hashable-1.3.3.0-Ob7F4bz7SrJSfcuDhkmwM
    split-0.2.3.4-1quTMurJlIxHAlbX9QCpKs text-1.2.4.1
    transformers-0.5.6.2
    unordered-containers-0.2.14.0-85xhml3fqIC6ZwgIEgRSE
    vector-0.12.3.1-1QSAcoQ4BjrEDZahKaKVTn
    vector-algorithms-0.8.0.4-HQn4at3zGahDO6SjfAITnz

haddock-interfaces:
    /usr/share/doc/haskell-mono-traversable/html/mono-traversable.haddock

haddock-html:         /usr/share/doc/haskell-mono-traversable/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
